==> qtjambi-uic-5.15.18-sources.jar: io/qt/uic/ui4/DomStringPropertySpecification.java <==
package io.qt.uic.ui4;

import io.qt.*;


/**
 * @hidden
 * <p>Java wrapper for Qt class <code>DomStringPropertySpecification</code></p>
 */
public class DomStringPropertySpecification extends QtObject
{
    static {
        QtJambi_LibraryUtilities.initialize();
    }
    
    
    /**
     * <p>See <code>DomStringPropertySpecification::<wbr/>DomStringPropertySpecification()</code></p>
     */
    public DomStringPropertySpecification(){
        super((QPrivateConstructor)null);
        initialize_native(this);
    }
    
    private native static void initialize_native(DomStringPropertySpecification instance);
    
    /**
     * <p>See <code>DomStringPropertySpecification::<wbr/>attributeName()const</code></p>
     */
    @QtUninvokable
    public final java.lang.@NonNull String attributeName(){
        return attributeName_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native java.lang.String attributeName_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <code>DomStringPropertySpecification::<wbr/>attributeNotr()const</code></p>
     */
    @QtUninvokable
    public final java.lang.@NonNull String attributeNotr(){
        return attributeNotr_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native java.lang.String attributeNotr_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <code>DomStringPropertySpecification::<wbr/>attributeType()const</code></p>
     */
    @QtUninvokable
    public final java.lang.@NonNull String attributeType(){
        return attributeType_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native java.lang.String attributeType_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <code>DomStringPropertySpecification::<wbr/>clearAttributeName()</code></p>
     */
    @QtUninvokable
    public final void clearAttributeName(){
        clearAttributeName_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native void clearAttributeName_native(long __this__nativeId);
    
    /**
     * <p>See <code>DomStringPropertySpecification::<wbr/>clearAttributeNotr()</code></p>
     */
    @QtUninvokable
    public final void clearAttributeNotr(){
        clearAttributeNotr_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native void clearAttributeNotr_native(long __this__nativeId);
    
    /**
     * <p>See <code>DomStringPropertySpecification::<wbr/>clearAttributeType()</code></p>
     */
    @QtUninvokable
    public final void clearAttributeType(){
        clearAttributeType_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native void clearAttributeType_native(long __this__nativeId);
    
    /**
     * <p>See <code>DomStringPropertySpecification::<wbr/>hasAttributeName()const</code></p>
     */
    @QtUninvokable
    public final boolean hasAttributeName(){
        return hasAttributeName_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native boolean hasAttributeName_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <code>DomStringPropertySpecification::<wbr/>hasAttributeNotr()const</code></p>
     */
    @QtUninvokable
    public final boolean hasAttributeNotr(){
        return hasAttributeNotr_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native boolean hasAttributeNotr_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <code>DomStringPropertySpecification::<wbr/>hasAttributeType()const</code></p>
     */
    @QtUninvokable
    public final boolean hasAttributeType(){
        return hasAttributeType_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native boolean hasAttributeType_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <code>DomStringPropertySpecification::<wbr/>read(QXmlStreamReader&amp;)</code></p>
     */
    @QtUninvokable
    public final void read(io.qt.core.@StrictNonNull QXmlStreamReader reader){
        java.util.Objects.requireNonNull(reader, "Argument 'reader': null not expected.");
        read_native_ref_QXmlStreamReader(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(reader));
    }
    
    @QtUninvokable
    private native void read_native_ref_QXmlStreamReader(long __this__nativeId, long reader);
    
    /**
     * <p>See <code>DomStringPropertySpecification::<wbr/>setAttributeName(QString)</code></p>
     */
    @QtUninvokable
    public final void setAttributeName(java.lang.@NonNull String a){
        setAttributeName_native_cref_QString(QtJambi_LibraryUtilities.internal.nativeId(this), a);
    }
    
    @QtUninvokable
    private native void setAttributeName_native_cref_QString(long __this__nativeId, java.lang.String a);
    
    /**
     * <p>See <code>DomStringPropertySpecification::<wbr/>setAttributeNotr(QString)</code></p>
     */
    @QtUninvokable
    public final void setAttributeNotr(java.lang.@NonNull String a){
        setAttributeNotr_native_cref_QString(QtJambi_LibraryUtilities.internal.nativeId(this), a);
    }
    
    @QtUninvokable
    private native void setAttributeNotr_native_cref_QString(long __this__nativeId, java.lang.String a);
    
    /**
     * <p>See <code>DomStringPropertySpecification::<wbr/>setAttributeType(QString)</code></p>
     */
    @QtUninvokable
    public final void setAttributeType(java.lang.@NonNull String a){
        setAttributeType_native_cref_QString(QtJambi_LibraryUtilities.internal.nativeId(this), a);
    }
    
    @QtUninvokable
    private native void setAttributeType_native_cref_QString(long __this__nativeId, java.lang.String a);
    
    /**
     * <p>See <code>DomStringPropertySpecification::<wbr/>write(QXmlStreamWriter&amp;,<wbr/>QString)const</code></p>
     */
    @QtUninvokable
    public final void write(io.qt.core.@StrictNonNull QXmlStreamWriter writer, java.lang.@NonNull String tagName){
        java.util.Objects.requireNonNull(writer, "Argument 'writer': null not expected.");
        write_native_ref_QXmlStreamWriter_cref_QString_constfct(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(writer), tagName);
    }
    
    @QtUninvokable
    private native void write_native_ref_QXmlStreamWriter_cref_QString_constfct(long __this__nativeId, long writer, java.lang.String tagName);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     * @hidden
     */
    @NativeAccess
    protected DomStringPropertySpecification(QPrivateConstructor p) { super(p); } 
    
    
    /**
     * <p>Overloaded function for {@link #write(io.qt.core.QXmlStreamWriter, java.lang.String)}
     *  with <code>tagName = (String)null</code>.</p>
     */
    @QtUninvokable
    public final void write(io.qt.core.@StrictNonNull QXmlStreamWriter writer) {
        write(writer, (String)null);
    }
}

==> qtjambi-uic-6.2.12-sources.jar: io/qt/uic/ui4/DomStringPropertySpecification.java <==
package io.qt.uic.ui4;

import io.qt.*;


/**
 * <p>Java wrapper for Qt class DomStringPropertySpecification</p>
 */
public class DomStringPropertySpecification extends QtObject
{
    static {
        QtJambi_LibraryUtilities.initialize();
    }
    
    
    public DomStringPropertySpecification(){
        super((QPrivateConstructor)null);
        initialize_native(this);
    }
    
    private native static void initialize_native(DomStringPropertySpecification instance);
    
    @QtUninvokable
    public final java.lang.@NonNull String attributeName(){
        return attributeName_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native java.lang.String attributeName_native_constfct(long __this__nativeId);
    
    @QtUninvokable
    public final java.lang.@NonNull String attributeNotr(){
        return attributeNotr_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native java.lang.String attributeNotr_native_constfct(long __this__nativeId);
    
    @QtUninvokable
    public final java.lang.@NonNull String attributeType(){
        return attributeType_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native java.lang.String attributeType_native_constfct(long __this__nativeId);
    
    @QtUninvokable
    public final void clearAttributeName(){
        clearAttributeName_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native void clearAttributeName_native(long __this__nativeId);
    
    @QtUninvokable
    public final void clearAttributeNotr(){
        clearAttributeNotr_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native void clearAttributeNotr_native(long __this__nativeId);
    
    @QtUninvokable
    public final void clearAttributeType(){
        clearAttributeType_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native void clearAttributeType_native(long __this__nativeId);
    
    @QtUninvokable
    public final boolean hasAttributeName(){
        return hasAttributeName_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native boolean hasAttributeName_native_constfct(long __this__nativeId);
    
    @QtUninvokable
    public final boolean hasAttributeNotr(){
        return hasAttributeNotr_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native boolean hasAttributeNotr_native_constfct(long __this__nativeId);
    
    @QtUninvokable
    public final boolean hasAttributeType(){
        return hasAttributeType_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native boolean hasAttributeType_native_constfct(long __this__nativeId);
    
    @QtUninvokable
    public final void read(io.qt.core.@StrictNonNull QXmlStreamReader reader){
        java.util.Objects.requireNonNull(reader, "Argument 'reader': null not expected.");
        read_native_ref_QXmlStreamReader(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(reader));
    }
    
    @QtUninvokable
    private native void read_native_ref_QXmlStreamReader(long __this__nativeId, long reader);
    
    @QtUninvokable
    public final void setAttributeName(java.lang.@NonNull String a){
        setAttributeName_native_cref_QString(QtJambi_LibraryUtilities.internal.nativeId(this), a);
    }
    
    @QtUninvokable
    private native void setAttributeName_native_cref_QString(long __this__nativeId, java.lang.String a);
    
    @QtUninvokable
    public final void setAttributeNotr(java.lang.@NonNull String a){
        setAttributeNotr_native_cref_QString(QtJambi_LibraryUtilities.internal.nativeId(this), a);
    }
    
    @QtUninvokable
    private native void setAttributeNotr_native_cref_QString(long __this__nativeId, java.lang.String a);
    
    @QtUninvokable
    public final void setAttributeType(java.lang.@NonNull String a){
        setAttributeType_native_cref_QString(QtJambi_LibraryUtilities.internal.nativeId(this), a);
    }
    
    @QtUninvokable
    private native void setAttributeType_native_cref_QString(long __this__nativeId, java.lang.String a);
    
    /**
     * <p>Overloaded function for {@link #write(io.qt.core.QXmlStreamWriter, java.lang.String)}
     *  with <code>tagName = (String)null</code>.</p>
     */
    @QtUninvokable
    public final void write(io.qt.core.@StrictNonNull QXmlStreamWriter writer) {
        write(writer, (String)null);
    }
    
    @QtUninvokable
    public final void write(io.qt.core.@StrictNonNull QXmlStreamWriter writer, java.lang.@NonNull String tagName){
        java.util.Objects.requireNonNull(writer, "Argument 'writer': null not expected.");
        write_native_ref_QXmlStreamWriter_cref_QString_constfct(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(writer), tagName);
    }
    
    @QtUninvokable
    private native void write_native_ref_QXmlStreamWriter_cref_QString_constfct(long __this__nativeId, long writer, java.lang.String tagName);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @NativeAccess
    protected DomStringPropertySpecification(QPrivateConstructor p) { super(p); } 
    
}
